import arcpy

# Set overwrite option
arcpy.env.overwriteOutput = True

#Read the parameter values:
#1. Input File
#2. Street field name in the Input file
#3. Naming File
#4. Field name containing Street Names

inputFile = arcpy.GetParameterAsText(0)
inputField = arcpy.GetParameterAsText(1)
nameFile = arcpy.GetParameterAsText(2)
fieldName = arcpy.GetParameterAsText(3)


# KEEPING ORIGINAL LAYERS (NOT CREATING ADDITIONAL "JOINED" LAYER)
# Create FeatureLayers
arcpy.MakeFeatureLayer_management(inputFile, "lyr_Segments")
arcpy.MakeFeatureLayer_management(nameFile, "lyr_Centerlines")

#dissolve the Centerlines layer
arcpy.Dissolve_management ("lyr_Centerlines", "lyr_dissolved", fieldName, "", "Multi_Part", "DISSOLVE_LINES")

#buffer the dissolved Centerlines layer
arcpy.Buffer_analysis ("lyr_dissolved", "lyr_buffer", "50 Feet", "", "", "", "")

#Delete any centerlines that will not be used
arcpy.SelectLayerByLocation_management("lyr_buffer", "INTERSECT", "lyr_Segments", "", "NEW_SELECTION")
arcpy.CopyFeatures_management("lyr_buffer", "lyr_selected")


# Create a search cursor for buffer
rows = arcpy.SearchCursor("lyr_selected")
for row in rows:
    #Select each CL, and then select all intersecting segments and calculate the Street field
    # NOTE: If you are not using shapefiles, then you'll have to change the FID in the line below to OBJECTID (or similar)
    arcpy.SelectLayerByAttribute_management("lyr_selected", "NEW_SELECTION", "\"OBJECTID\" = " + str(row.getValue("OBJECTID")))
    arcpy.SelectLayerByLocation_management("lyr_Segments", ("COMPLETELY_WITHIN"), "lyr_selected", "", "NEW_SELECTION")
    arcpy.CalculateField_management("lyr_Segments", inputField, "'{0}'".format(str(row.getValue(fieldName))), "PYTHON_9.3", "")
    print "Finished processing " + str(row.getValue(fieldName))
